diff --git a/src/deck/data.ts b/src/deck/data.ts
index 061490c..8cda8fa 100644
--- a/src/deck/data.ts
+++ b/src/deck/data.ts
@@ -88,7 +88,7 @@ export const entities: Entity[] = [
icon: 'Building2',
},
{
- id: 'festivals',
+ id: 'summit',
name: 'Pop-up Summit Gatherings',
role: 'Travelling gatherings',
kind: 'Travelling ยท ephemeral',
diff --git a/src/deck/gallery.ts b/src/deck/gallery.ts
index 96a7599..e98c912 100644
--- a/src/deck/gallery.ts
+++ b/src/deck/gallery.ts
@@ -74,7 +74,7 @@ export const gallerySections: GallerySection[] = [
{
id: 'summit',
label: 'Summit Gathering',
- entityName: entityById('festivals').name,
+ entityName: entityById('summit').name,
accent: 'rose',
folder: 'src/deck/gallery/summit/',
images: toImages(summit),
diff --git a/src/deck/components/MyceliumNetwork.vue b/src/deck/components/MyceliumNetwork.vue
index 939dac8..da5e6c8 100644
--- a/src/deck/components/MyceliumNetwork.vue
+++ b/src/deck/components/MyceliumNetwork.vue
@@ -73,21 +73,21 @@ function thread([a, b]: [number, number], i: number) {
}
const sol = entityById('sollunar') // city
-const fest = entityById('festivals') // travelling
+const fest = entityById('summit') // travelling
const cha = entityById('chateau') // farm
// surface flowers: the three experiences + two faint "future" ones.
// (Lab 484 is the mycelium itself โ the network below, not a flower.)
const flowers = [
{ x: 230, kind: 'bloom', color: 'var(--color-indigo)', name: sol.name, tag: sol.role },
- { x: 500, kind: 'festival', color: 'var(--color-rose)', name: fest.name, tag: fest.role },
+ { x: 500, kind: 'summit', color: 'var(--color-rose)', name: fest.name, tag: fest.role },
{ x: 770, kind: 'bloom', color: 'var(--color-clay)', name: cha.name, tag: cha.role },
{ x: 100, kind: 'ghost' },
{ x: 900, kind: 'ghost' },
] as const
-// small pop-up caps for the ephemeral festival flower
-const festivalCaps = [
+// small pop-up caps for the ephemeral summit flower
+const summitCaps = [
{ dx: -18, dy: -58, r: 15 },
{ dx: 0, dy: -74, r: 20 },
{ dx: 20, dy: -60, r: 14 },
@@ -196,8 +196,8 @@ const festivalCaps = [
-
-
+
+
-
-
+
+
@@ -363,8 +363,8 @@ const festivalCaps = [
}
}
-/* festival cluster gently floats + fades โ it's ephemeral */
-.myc-festival {
+/* summit cluster gently floats + fades โ it's ephemeral */
+.myc-summit {
transform-box: fill-box;
transform-origin: bottom center;
animation: myc-float 4.5s ease-in-out infinite;
@@ -400,7 +400,7 @@ const festivalCaps = [
.myc-pulse,
.myc-node,
.myc-cap,
- .myc-festival,
+ .myc-summit,
.myc-plus {
animation: none;
}